@@ -2,7 +2,7 @@
 import logging
 
 
-def get_module_logger(mod_name):
+def get_module_logger(mod_name) -> logging.Logger:
     """
     To use this, do logger = get_module_logger(__name__)
     """
